﻿namespace Microsoft.ExternalResearch.CreativeCommons.Excel
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using System.Xml.Linq;
    using Office = Microsoft.Office.Core;
    using Microsoft.Office.Interop.Excel;
    using System.Runtime.InteropServices;
    using Microsoft.Office.Core;
    using Microsoft.ExternalResearch.CreativeCommons.Common;
    using System.IO;
    using System.Xml;

    /// <summary>
    /// Represents the Creative Commons Add-in for Microsoft Excel.
    /// </summary>
    public partial class ThisAddIn
    {
        /// <summary>
        /// Represents the Excel application object.
        /// </summary>
        private static Application excelApplication;

        /// <summary>
        /// Raised when the application starts.
        /// </summary>
        public static event EventHandler ApplicationStartedEvent;

        /// <summary>
        /// Gets or sets the Excel application object.
        /// </summary>
        public static Application ExcelApplication
        {
            get
            {
                return excelApplication;
            }

            set
            {
                excelApplication = value;
            }
        }

        /// <summary>
        /// Raises the ApplicationStarted event.
        /// </summary>
        /// <param name="sender">Sender of the event.</param>
        /// <param name="e">Event arguments.</param>
        private void ThisAddInStartup(object sender, System.EventArgs e)
        {
            ThisAddIn.ExcelApplication = this.Application;

            if (null != ApplicationStartedEvent)
            {
                ApplicationStartedEvent(this, null);
            }
        }
        /// <summary>
        /// Gets a value indicating whether a workbook is opened, false otherwise.
        /// </summary>
        public static bool HasWorkbook()
        {
            bool hasWorkbook = false;

            if (null != ThisAddIn.ExcelApplication.ActiveWorkbook)
            {
                hasWorkbook = true;
            }
            return hasWorkbook;
        }
        /// <summary>
        /// Removes the document property for Creative Commons license.
        /// </summary>
        public static void RemoveLicenseFromDocument()
        {
            DocumentProperties customProperties = (DocumentProperties)ThisAddIn.ExcelApplication.ActiveWorkbook.CustomDocumentProperties;

            if (null != Helper.ReadLicenseInfo(customProperties))
            {
                customProperties[Helper.LicenseIdPropertyName].Delete();
                customProperties[Helper.LicenseUrlPropertyName].Delete();
                customProperties[Helper.LicenseXmlPropertyName].Delete();
            }
        }
        #region VSTO generated code

        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InternalStartup()
        {
            this.Startup += new System.EventHandler(ThisAddInStartup);
        }

        #endregion
    }
}
